@@ -36,17 +36,20 @@ metaData <- function(x) {
 #' @importFrom xts xts
 #' @importFrom xts as.xts
 #' @export
-Quandl <- function(code, type = c('raw', 'ts', 'zoo', 'xts', 'timeSeries'), transform = c('', 'diff', 'rdiff', 'normalize', 'cumul', 'rdiff_from'), collapse = c('', 'daily', 'weekly', 'monthly', 'quarterly', 'annual'), order = c('desc', 'asc'), meta = FALSE, force_irregular = FALSE, ...) {
-  params = list()
+Quandl <- function(code, type = c("raw", "ts", "zoo", "xts", "timeSeries"),
+                   transform = c("", "diff", "rdiff", "normalize", "cumul", "rdiff_from"),
+                   collapse = c("", "daily", "weekly", "monthly", "quarterly", "annual"),
+                   order = c("desc", "asc"), meta = FALSE, force_irregular = FALSE, ...) {
+  params <- list()
   ## Default to entire dataset
-  col = NULL
+  col <- NULL
   ## Check params
   type                    <- match.arg(type)
   params$transform   <- match.arg(transform)
   params$collapse         <- match.arg(collapse)
   params$order       <- match.arg(order)
 
-  if (type == 'timeSeries' && system.file(package = type) == "") {
+  if (type == "timeSeries" && system.file(package = type) == "") {
     stop("Package ", type, " needed to use this type", call. = FALSE)
   }
 
@@ -57,11 +60,11 @@ Quandl <- function(code, type = c('raw', 'ts', 'zoo', 'xts', 'timeSeries'), tran
       return(365)
     } else {
       switch(freq,
-           'daily'    = 365,
-           'weekly'   = 52,
-           'monthly'  = 12,
-           'quarterly' = 4,
-           'yearly'   = 1,
+           "daily"    = 365,
+           "weekly"   = 52,
+           "monthly"  = 12,
+           "quarterly" = 4,
+           "yearly"   = 1,
            1)
     }
   }
@@ -79,13 +82,13 @@ Quandl <- function(code, type = c('raw', 'ts', 'zoo', 'xts', 'timeSeries'), tran
     codearray <- strsplit(code, "/")
     if (length(codearray[[1]]) == 3) {
       col <- codearray[[1]][3]
-      code <- paste(codearray[[1]][1:2], collapse='/')
+      code <- paste(codearray[[1]][1:2], collapse = "/")
     } else if (length(strsplit(code, "\\.")[[1]]) == 2) {
       col <- strsplit(code, "\\.")[[1]][2]
       code <- strsplit(code, "\\.")[[1]][1]
     } else if (length(strsplit(code, "\\.")[[1]]) == 3) {
       col <- strsplit(code, "\\.")[[1]][2]
-      code <- paste(strsplit(code, "\\.")[[1]][1:2], collapse='/')
+      code <- paste(strsplit(code, "\\.")[[1]][1:2], collapse = "/")
     }
 
     return(c(code, col))
@@ -107,33 +110,33 @@ Quandl <- function(code, type = c('raw', 'ts', 'zoo', 'xts', 'timeSeries'), tran
   }
 
   if (!is.null(params$transformation)) {
-    warning("argument transformation is deprecated; please use transform instead.", 
+    warning("argument transformation is deprecated; please use transform instead.",
       call. = FALSE)
   }
 
   if (!is.null(params$sort)) {
-    warning("argument sort is deprecated; please use order instead.", 
+    warning("argument sort is deprecated; please use order instead.",
       call. = FALSE)
   }
 
   ## Download and parse data
   errors <- list()
-  if(length(code) == 1) {
+  if (length(code) == 1) {
     code_col <- format.code(code)
     code <- code_col[1]
     col <- code_col[2]
 
-    if(!is.null(col) && !is.na(col)) {
+    if (!is.null(col) && !is.na(col)) {
       params$column_index <- col
     }
 
-    if(meta) {
+    if (meta) {
       params$meta <- meta
     }
 
     # download data
     data <- Quandl.dataset.get(code, params)
-    if(params$collapse != '') {
+    if (params$collapse != "") {
       freq <- frequency2integer(params$collapse)
     } else {
       freq <- frequency2integer(attr(data, "freq"))
@@ -141,40 +144,40 @@ Quandl <- function(code, type = c('raw', 'ts', 'zoo', 'xts', 'timeSeries'), tran
   } else {
     data <- NULL
 
-    for(c in code) {
+    for (c in code) {
       tmp.params <- params
       code_col <- format.code(c)
       c <- code_col[1]
       col <- code_col[2]
 
-      if(!is.null(col) && !is.na(col)) {
+      if (!is.null(col) && !is.na(col)) {
         tmp.params$column_index <- col
       }
 
-      merge_data <- tryCatch(Quandl.dataset.get(c, tmp.params), error=function(e) {
-        d <- data.frame(Date=character(0), ERROR=numeric(0))
+      merge_data <- tryCatch(Quandl.dataset.get(c, tmp.params), error = function(e) {
+        d <- data.frame(Date = character(0), ERROR = numeric(0))
         attr(d, "errors") <- e
         return(d)
       })
 
-      if(is.null(col)) {
+      if (is.null(col)) {
         suppressWarnings(errors[c] <- attr(merge_data, "errors"))
       } else {
-        suppressWarnings(errors[paste(c,col,sep=".")] <- attr(merge_data, "errors"))
+        suppressWarnings(errors[paste(c, col, sep = ".")] <- attr(merge_data, "errors"))
       }
 
-      for(i in 2:length(names(merge_data))) {
-        names(merge_data)[i] <- paste(sub('/','.',c), names(merge_data)[i], sep=' - ')
+      for (i in 2:length(names(merge_data))) {
+        names(merge_data)[i] <- paste(sub("/", ".", c), names(merge_data)[i], sep = " - ")
       }
 
-      if(is.null(data)) {
+      if (is.null(data)) {
         data <- merge_data
       } else {
-        data <- merge(data, merge_data, by=1, all=TRUE)
+        data <- merge(data, merge_data, by = 1, all = TRUE)
       }
     }
 
-    if(params$collapse != '') {
+    if (params$collapse != "") {
       freq <- frequency2integer(params$collapse)
     } else {
       freq <- 365
@@ -190,50 +193,60 @@ Quandl <- function(code, type = c('raw', 'ts', 'zoo', 'xts', 'timeSeries'), tran
     # Deal with regularly spaced time series first
     if (freq %in% c(1, 4, 12) && !force_irregular) {
       # Build regular zoo with correct frequency
-      if(freq == 1) {
-        data_out <- zoo(data[,-1], frequency = freq, as.year(data[,1]))
+      if (freq == 1) {
+        data_out <- zoo::zoo(data[, -1], frequency = freq, as.year(data[, 1]))
       } else if (freq == 4) {
-        data_out <- zoo(data[,-1], frequency = freq, as.yearqtr(data[,1]))
+        data_out <- zoo::zoo(
+          data[, -1], frequency = freq, as.yearqtr(data[, 1])
+        )
       } else if (freq == 12) {
-        data_out <- zoo(data[,-1], frequency = freq, as.yearmon(data[,1]))
+        data_out <- zoo::zoo(
+          data[, -1], frequency = freq, as.yearmon(data[, 1])
+        )
       }
 
       # Convert to type
       if (type == "ts") {
         data_out <- stats::as.ts(data_out)
       } else if (type == "zoo") {
-        data_out <- as.zooreg(data_out)
+        data_out <- zoo::as.zooreg(data_out)
       } else if (type == "xts") {
-        data_out <- if(freq == 1) {
-          xts(data[, -1], frequency = 1, order.by=data[, 1])
+        data_out <- if (freq == 1) {
+          xts::xts(data[, -1], frequency = 1, order.by = data[, 1])
         } else  {
-          as.xts(data_out)
+          xts::as.xts(data_out)
         }
         if (freq != stats::frequency(data_out)) {
           warning("xts has a non-standard meaning for 'frequency'.")
         }
       } else if (type == "timeSeries") {
-        data_out <- timeSeries::timeSeries(data=data[, -1], charvec=data[, 1])
+        data_out <- timeSeries::timeSeries(
+          data = data[, -1],
+          charvec = data[, 1]
+        )
       }
 
-    } else if (type=="zoo" || type=="ts") {
+    } else if (type == "zoo" || type == "ts") {
       # Time series is not regularly spaced
       if (type == "ts") {
-        warning("Type 'ts' does not support frequency ", freq, ". Returning zoo.")
+        warning(
+          "Type 'ts' does not support frequency ", freq,
+          ". Returning zoo."
+        )
       }
-      data_out <- zoo(data[, -1], order.by=data[, 1])
+      data_out <- zoo::zoo(data[, -1], order.by = data[, 1])
     } else if (type == "xts") {
-      data_out <- xts(data[, -1], order.by=data[, 1])
+      data_out <- xts::xts(data[, -1], order.by = data[, 1])
     } else if (type == "timeSeries") {
-      data_out <- timeSeries::timeSeries(data = data[, -1], charvec=data[, 1])
+      data_out <- timeSeries::timeSeries(data = data[, -1], charvec = data[, 1])
     }
   }
 
-  if(length(errors) > 0) {
+  if (length(errors) > 0) {
     attr(data_out, "errors") <- errors
   }
 
-  if(!is.null(meta)) {
+  if (!is.null(meta)) {
     attr(data_out, "meta") <- meta
   }
 
@@ -254,7 +267,7 @@ Quandl <- function(code, type = c('raw', 'ts', 'zoo', 'xts', 'timeSeries'), tran
 #' }
 #' @export
 Quandl.dataset.get <- function(code, params) {
-  if(!is.null(params$meta) && params$meta) {
+  if (!is.null(params$meta) && params$meta) {
     meta <- params$meta
     params[[which(names(params) == "meta")]] <- NULL
   } else {
@@ -262,30 +275,20 @@ Quandl.dataset.get <- function(code, params) {
   }
 
   path <- paste0("datasets/", code)
-  json <- do.call(quandl.api, c(path=path, params))$dataset
+  json <- do.call(quandl.api, c(path = path, params))$dataset
 
   if (length(json$data) == 0) {
     stop("Requested Entity does not exist.")
   }
 
-  ## Detect frequency
-  # freq <- frequency2integer(json$frequency)
   if (!is.null(params$column_index) && length(json$column_names) > 2) {
-    json$column_names = json$column_names[c(1, as.numeric(params$column_index)+1)]
+    selected_cols <- c(1, as.numeric(params$column_index) + 1)
+    json$column_names <- json$column_names[selected_cols]
   }
 
-  ## Shell data from JSON's list
-  # data <- tryCatch(as.data.frame(matrix(unlist(json$data), ncol = length(json$column_names), byrow = TRUE), stringsAsFactors=FALSE),
-  #                  warning=function(w) {
-  #                    warning(w)
-  #                    warning(paste("This warning is most likely the result of a data structure error. If the output of this function does not make sense please email connect@quandl.com with the Quandl code: ", code), call. = FALSE)
-  #                    return(suppressWarnings(as.data.frame(matrix(unlist(json$data), ncol = length(json$column_names), byrow = TRUE),stringsAsFactors=FALSE)))
-  #                  })
-  data <- as.data.frame(json$data, stringsAsFactors=FALSE)
-  # data <- do.call(rbind, lapply(json$data, rbind))
-  # data[apply(data, 1:2,is.null)] <- NA
+  data <- as.data.frame(json$data, stringsAsFactors = FALSE)
   names(data) <- json$column_names
-  data[,1]    <- as.Date(data[, 1])
+  data[, 1]    <- as.Date(data[, 1])
 
   ## Transform values to numeric
   if (ncol(data) > 2) {
